"use strict";

exports.__esModule = true;
exports.CLink = void 0;

var _vueUtils = require("@chakra-ui/vue-utils");

var _vue = require("vue");

var _vueSystem = require("@chakra-ui/vue-system");

var _utils = require("@chakra-ui/utils");

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/**
 * Links are accessible elements used primarily for navigation.
 *
 * It integrates well with other routing libraries like
 * Vue Router and Nuxt.js Link.
 *
 * @example
 *
 * ```vue
 * <CLink as="router-link" to="/home">Home</CLink>
 * ```
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/link
 */
var CLink = (0, _vue.defineComponent)({
  props: _extends({
    as: {
      type: [Object, String],
      "default": 'a'
    },
    isExternal: Boolean
  }, _vueUtils.vueThemingProps),
  setup: function setup(props, _ref) {
    var slots = _ref.slots,
        attrs = _ref.attrs;
    return function () {
      var themingProps = (0, _vue.computed)(function () {
        return (0, _utils.filterUndefined)({
          colorScheme: props.colorScheme,
          variant: props.variant,
          size: props.size,
          styleConfig: props.styleConfig
        });
      });
      var styles = (0, _vueSystem.useStyleConfig)('Link', themingProps.value);
      return (0, _vue.h)((0, _vueSystem.chakra)(props.as, {
        label: 'link'
      }), _extends({
        target: props.isExternal ? '_blank' : undefined,
        rel: props.isExternal ? 'noopener noreferrer' : undefined,
        __css: styles.value
      }, attrs), slots);
    };
  }
});
exports.CLink = CLink;
//# sourceMappingURL=link.js.map