function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import { vueThemingProps } from '@chakra-ui/vue-utils';
import { h, defineComponent, computed } from 'vue';
import { chakra, useStyleConfig } from '@chakra-ui/vue-system';
import { filterUndefined } from '@chakra-ui/utils';

/**
 * Links are accessible elements used primarily for navigation.
 *
 * It integrates well with other routing libraries like
 * Vue Router and Nuxt.js Link.
 *
 * @example
 *
 * ```vue
 * <CLink as="router-link" to="/home">Home</CLink>
 * ```
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/link
 */
export var CLink = defineComponent({
  props: _extends({
    as: {
      type: [Object, String],
      default: 'a'
    },
    isExternal: Boolean
  }, vueThemingProps),

  setup(props, _ref) {
    var {
      slots,
      attrs
    } = _ref;
    return () => {
      var themingProps = computed(() => filterUndefined({
        colorScheme: props.colorScheme,
        variant: props.variant,
        size: props.size,
        styleConfig: props.styleConfig
      }));
      var styles = useStyleConfig('Link', themingProps.value);
      return h(chakra(props.as, {
        label: 'link'
      }), _extends({
        target: props.isExternal ? '_blank' : undefined,
        rel: props.isExternal ? 'noopener noreferrer' : undefined,
        __css: styles.value
      }, attrs), slots);
    };
  }

});
//# sourceMappingURL=link.js.map