function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import { h, defineComponent, computed, Fragment, createVNode } from 'vue';
import { chakra } from '@chakra-ui/vue-system';
import { getDividerStyles, getStackStyles, selector } from './stack.utils';
import { getValidChildren, SNAO, SAO } from '@chakra-ui/vue-utils';
export var CStackDivider = defineComponent({
  setup(_, _ref) {
    var {
      attrs
    } = _ref;
    return () => {
      return h(chakra('div', {
        label: 'stack__divider',
        borderWidth: 0,
        alignSelf: 'stretch',
        borderColor: 'inherit',
        width: 'auto',
        height: 'auto',
        __css: attrs.__css
      }));
    };
  }

});
export var CStackItem = defineComponent({
  setup(_, _ref2) {
    var {
      attrs
    } = _ref2;
    return () => {
      return h(chakra('div', _extends({
        label: 'stack__item'
      }, attrs, {
        display: 'inline-block',
        flex: '0 0 auto',
        minWidth: 0,
        __css: attrs.__css
      })));
    };
  }

});
var stackProps = {
  as: {
    type: [Object, String],
    default: 'div'
  },
  align: SAO,
  justify: SAO,
  wrap: SAO,
  spacing: {
    type: SNAO,
    default: '0.5rem'
  },
  direction: SAO,
  // todo: divider
  divider: [Object, Boolean],
  shouldWrapChildren: [Boolean],
  isInline: [Boolean]
};
/**
 * Stacks help you easily create flexible and automatically distributed layouts
 *
 * You can stack elements in the horizontal or vertical direction,
 * and apply a space or/and divider between each element.
 *
 * It uses `display: flex` internally and renders a `div`.
 *
 * @see Docs https://vue.chakra-ui.com/docs/layout/stack
 *
 */

export var CStack = defineComponent({
  name: 'CStack',
  props: stackProps,

  setup(props, _ref3) {
    var {
      slots,
      attrs
    } = _ref3;
    var direction = computed(() => {
      var _props$direction;

      return props.isInline ? 'row' : (_props$direction = props.direction) != null ? _props$direction : 'column';
    });
    var styles = computed(() => getStackStyles({
      direction: direction.value,
      spacing: props.spacing
    }));
    var dividerStyle = computed(() => getDividerStyles({
      spacing: props.spacing,
      direction: direction.value
    }));
    var hasDivider = computed(() => !!props.divider);
    var shouldUseChildren = computed(() => !props.shouldWrapChildren && !hasDivider.value);
    return () => {
      var validChildren = getValidChildren(slots);
      var clones = shouldUseChildren.value ? validChildren : validChildren.map((child, index) => {
        var isLast = index + 1 === validChildren.length;
        var wrappedChild = createVNode(CStackItem, {
          key: index
        }, child);

        var _child = props.shouldWrapChildren ? wrappedChild : child;

        if (!hasDivider.value) return _child; // todo: temporary divider

        var clonedDivider = createVNode(CStackDivider, {
          borderColor: 'blue.200',
          __css: dividerStyle.value
        });

        var _divider = isLast ? null : clonedDivider;

        return createVNode(Fragment, {
          key: index
        }, [_child, _divider]);
      });
      return h(chakra('div', {
        label: attrs.label ? attrs.label : 'stack',
        // CHStack and CVStack
        display: 'flex',
        alignItems: props.align,
        justifyContent: props.justify,
        flexDirection: styles.value.flexDirection,
        flexWrap: props.wrap,
        __css: hasDivider.value ? {} : {
          [selector]: styles.value[selector]
        }
      }), () => clones);
    };
  }

});
/**
 * A view that arranges its children in a horizontal line.
 */

export var CHStack = defineComponent({
  name: 'CHStack',
  props: stackProps,

  setup(props, _ref4) {
    var {
      attrs,
      slots
    } = _ref4;
    return () => {
      return h(CStack, _extends({
        label: 'stack-horizontal',
        align: 'center'
      }, props, attrs, {
        direction: 'row'
      }), slots);
    };
  }

});
/**
 * A view that arranges its children in a vertical line.
 */

export var CVStack = defineComponent({
  name: 'CVStack',
  props: stackProps,

  setup(props, _ref5) {
    var {
      attrs,
      slots
    } = _ref5;
    return () => {
      return h(CStack, _extends({
        label: 'stack-vertical',
        align: 'center'
      }, props, attrs, {
        direction: 'column'
      }), slots);
    };
  }

});
//# sourceMappingURL=stack.js.map